# Installation

## Python

```commandline
pipx install camply
```

!!! note

    If you're using camply on your command line - it's recommended that you use a tool
    like [pipx](https://github.com/pypa/pipx) to easily manage the application in an isolated
    virtual environment. However you can always **`pip install camply`** as well.

[PyPI Link](https://pypi.python.org/pypi/camply/)

## Docker

```commandline
docker pull juftin/camply
```

[Docker Hub Link](https://hub.docker.com/r/juftin/camply)

\*\*_see [Running in Docker](how_to_run.md#running-in-docker)._
